/*
*Copyright©2023 National Fundamental Software of China Co., Ltd.
*(National Engineering Research Center of Fundamental Software).
*All Rights Reserved.
*
 * Author:     xiongwei <xiongwei@nfschina.com>
 *
 * Maintainer: xiongwei <xiongwei@nfschina.com>
 *
*This software is provided by the copyright holders - National Fundamental Software of China Co., Ltd.
*(National Engineering Research Center of Fundamental Software).
*The above copyright is protected by copyright laws in all countries andthe Universal Copyright Convention.
*National Fundamental Software of China Co., Ltd. (National Engineering Research Center of Fundamental Software)
*will reserve the right to take any necessary legal means against the unauthorized use of this software or any use that
*appears outside of National Fundamental Software of China Co., Ltd. ‘s
*(National Engineering Research Center of Fundamental Software's)
*intellectual property declaration.
*/

#ifndef _FSC_DEFENDER_H
#define _FSC_DEFENDER_H

#define FSC_PATH_MAX 128

/**
 * @brief 杀毒软件授权信息
 *
 */
typedef struct
fsc_antivirus_auth_info
{
    int type;                                 //授权类型 1 正式授权； 2 试用授权
    char expiration_date[32];    //授权到期时间，格式为 YYYY-MM-DD HH:MM:SS
}fsc_antivirus_auth_info;

/**
 * @brief 杀毒软件信息
 *
 */
typedef struct
fsc_antivirus_info
{
    char name[256];                             //软件名称
    char ver[64];                                   //版本号
    char release_date[32];                   //软件发布日期，格式为 YYYY-MM-DD
    char exec[FSC_PATH_MAX];           //程序路径,用于安全中心与该安全软件之间的用户操作调用接口
    char exec_scan[FSC_PATH_MAX];  //立即扫描，用于安全中心调用杀毒软件执行立即扫描功能
    char icon[FSC_PATH_MAX];            //程序图标,用于安全中心展示
    int upd_stat;                                    //程序更新状态，0-->已是最新状态，无需要更新，1-->有可用更新，2-->更新失败
    char vlib_ver[64];                            //病毒库版本，不能为空
    char vlib_date[32];                          //病毒库日期，格式为 YYYY-MM-DD
    int vlib_upd_stat;                             //病毒库授权类型，0-->未授权、试用时间，1-->正式授权，2-->试用授权，3-->联控制中心授权，没有授权过期概念
    fsc_antivirus_auth_info auth_info; //杀软授权信息
}fsc_antivirus_info;

/**
 * @brief 杀毒软件状态信息
 *
 */
typedef struct
fsc_antivirus_status
{
    int stat;                       //病毒扫描及监控状态，0-->未进行扫描，1-->当前正在扫描
    char scan_date[32];   //最近一次病毒扫描结束时间，格式为 YYYY-MM-DDHH:MM:SS
    int scan;                      //最近一次扫描发现的病毒数
    int deal;                       //本次扫描已处理的病毒
    int monitor;                //近 10 分钟内实时防护发现的病毒
} fsc_antivirus_status;

/**
 * @brief 安全组件状态
 *
 */
typedef struct fsc_trustapp_status
{
    int type;           //插件类型 0-->cpu, 1-->内存, 2-->固件， 3-->系统，4-->插件
    int state;          //插件状态 0-->未启用， 1-->启用
} fsc_trustapp_status;

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 杀毒软件注册接口
 *
 * @param uuid 杀毒软件注册时用于做唯一标识，整个生命周期不能改变
 * @param virus_info 杀毒软件信息
 * @return int ０：成功, 1：非法数据, 2：内存异常, 3：参数异常, 其他：信息上报异常
 */
int fsc_defender_register_antivirus(char *uuid, fsc_antivirus_info *virus_info);

/**
 * @brief 杀毒软件关闭前，注销接口
 *
 * @param uuid 杀毒软件注册时用于做唯一标识，整个生命周期不能改变
 * @return int ０：成功, 1：非法数据, 2：内存异常, 3：参数异常, 其他：信息上报异常
 */
int fsc_defender_unregister_antivirus(char *uuid);

/**
 * @brief 将杀毒软件信息上报至安全中心
 *
 * @param uuid 杀毒软件注册时用于做唯一标识，整个生命周期不能改变
 * @param virus_info 杀毒软件信息
 * @return int ０：成功, 1：非法数据, 2：内存异常, 3：参数异常, 其他：信息上报异常
 */
int fsc_defender_antivirus_info_upload(char *uuid, fsc_antivirus_info *virus_info);

/**
 * @brief 将系统安全状态上报至安全中心
 *
 * @param uuid 杀毒软件注册时用于做唯一标识，整个生命周期不能改变
 * @param virus_status 系统安全信息
 * @return int ０：成功, 1：非法数据, 2：内存异常, 3：参数异常, 其他：信息上报异常
 */
int fsc_defender_antivirus_status_upload(char *uuid, fsc_antivirus_status *virus_status);

/**
 * @brief 将安全组件状态上报至安全中心
 *
 * @param uuid 安全组件唯一标识，整个生命周期不能改变
 * @param status 安全组件状态
 * @return int ０：成功, 1：非法数据, 2：内存异常, 3：参数异常, 其他：信息上报异常
 */
int fsc_defender_trustapp_status_upload(char *uuid, fsc_trustapp_status *status);

#ifdef __cplusplus
}
#endif

#endif
